Documentation
¶
Index ¶
Constants ¶
const (
// Name is the name of this frontend.
Name = "empty"
)
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GAPI ¶
type GAPI struct {
// Wait should be true if we don't use any existing (stale) deploys.
// This means that if you start an empty GAPI, then it will immediately
// try to look for and run any existing deploys that have been stored in
// the cluster that it has connected to. If this is true, then it will
// only start on the next deploy. To be honest, we should probably never
// wait, but this was accidentally how it was initially implemented, so
// we'll change the default and add this in as a flag for now. We may
// remove this in the future unless someone has a good reason for
// needing it.
Wait bool
// contains filtered or unexported fields
}
GAPI implements the main lang GAPI interface.
func (*GAPI) Cli ¶
Cli takes an *Info struct, and returns our deploy if activated, and if there are any validation problems, you should return an error. If there is no deploy, then you should return a nil deploy and a nil error.
func (*GAPI) Err ¶
Err will contain the last error when Next shuts down. It waits for all the running processes to exit before it returns.
func (*GAPI) Info ¶
func (obj *GAPI) Info() *gapi.InfoResult
Info returns some data about the GAPI implementation.
Click to show internal directories.
Click to hide internal directories.